<?xml version="1.0" ?><!DOCTYPE TS><TS language="ru" version="2.1">
<context>
    <name>CDayMonthView</name>
    <message>
        <source>Monday</source>
        <translation>Понедельник</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>Вторник</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>Среда</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>Четверг</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>Пятница</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>Суббота</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>Воскресенье</translation>
    </message>
</context>
<context>
    <name>CDayWindow</name>
    <message>
        <source>Y</source>
        <translation>Г</translation>
    </message>
    <message>
        <source>M</source>
        <translation>М</translation>
    </message>
    <message>
        <source>D</source>
        <translation>Д</translation>
    </message>
</context>
<context>
    <name>CGraphicsView</name>
    <message>
        <source>New Event</source>
        <translation>Новое Событие</translation>
    </message>
</context>
<context>
    <name>CMonthGraphiview</name>
    <message>
        <source>Delete</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <source>You are deleting an event.</source>
        <translation>Вы удаляете событие.</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this event?</source>
        <translation>Вы уверены, что хотите удалить это событие?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <source>Do you want to delete all occurrences of this event, or only the selected occurrence?</source>
        <translation>Вы хотите удалить все записи этого события или только выбранную запись?</translation>
    </message>
    <message>
        <source>Delete All</source>
        <translation>Удалить все</translation>
    </message>
    <message>
        <source>Delete Only This Event</source>
        <translation>Удалить только это событие</translation>
    </message>
    <message>
        <source>Do you want to delete this and all future occurrences of this event, or only the selected occurrence?</source>
        <translation>Вы хотите удалить эту и все будущие записи этого события или только выбранную запись?</translation>
    </message>
    <message>
        <source>Delete All Future Events</source>
        <translation>Удалить все будущие события</translation>
    </message>
</context>
<context>
    <name>CMonthSchceduleNumButton</name>
    <message>
        <source>%1 more</source>
        <translation>%1 более</translation>
    </message>
</context>
<context>
    <name>CMonthView</name>
    <message>
        <source>New event</source>
        <translation>Новое событие</translation>
    </message>
    <message>
        <source>New Event</source>
        <translation>Новое Событие</translation>
    </message>
</context>
<context>
    <name>CMonthWindow</name>
    <message>
        <source>Y</source>
        <translation>Г</translation>
    </message>
</context>
<context>
    <name>CMySchceduleView</name>
    <message>
        <source>You are deleting an event.</source>
        <translation>Вы удаляете событие.</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this event?</source>
        <translation>Вы уверены, что хотите удалить это событие?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <source>Do you want to delete all occurrences of this event, or only the selected occurrence?</source>
        <translation>Вы хотите удалить все записи этого события или только выбранную запись?</translation>
    </message>
    <message>
        <source>Delete All</source>
        <translation>Удалить Всё</translation>
    </message>
    <message>
        <source>Delete Only This Event</source>
        <translation>Удалить Только Это Событие</translation>
    </message>
    <message>
        <source>Do you want to delete this and all future occurrences of this event, or only the selected occurrence?</source>
        <translation>Вы хотите удалить эту и все будущие записи этого события или только выбранную запись?</translation>
    </message>
    <message>
        <source>My Event</source>
        <translation>Моё Событие</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Редактировать</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Delete All Future Events</source>
        <translation>Удалить Все Будущие События</translation>
    </message>
</context>
<context>
    <name>CSchceduleDlg</name>
    <message>
        <source>New Event</source>
        <translation>Новое Событие</translation>
    </message>
    <message>
        <source>Edit Event</source>
        <translation>Изменить Событие</translation>
    </message>
    <message>
        <source>All occurrences of a repeating event must have the same all-day status.</source>
        <translation>Все повторяющиеся события должны иметь одинаковый статус в течение всего дня.</translation>
    </message>
    <message>
        <source>Do you want to change all occurrences?</source>
        <translation>Хотите изменить все записи?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <source>Change All</source>
        <translation>Изменить Всё</translation>
    </message>
    <message>
        <source>You are changing the repeating rule of this event.</source>
        <translation>Вы меняете повторяющееся правило этого события.</translation>
    </message>
    <message>
        <source>You are changing a repeating event.</source>
        <translation>Вы меняете повторяющееся событие.</translation>
    </message>
    <message>
        <source>Do you want to change only this occurrence of the event, or all occurrences?</source>
        <translation>Вы хотите изменить только эту запись события или все записи?</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Всё</translation>
    </message>
    <message>
        <source>Only This Event</source>
        <translation>Только Это Событие</translation>
    </message>
    <message>
        <source>Do you want to change only this occurrence of the event, or this and all future occurrences?</source>
        <translation>Вы хотите изменить только эту запись события или эту и все будущие записи?</translation>
    </message>
    <message>
        <source>All Future Events</source>
        <translation>Все Будущие События</translation>
    </message>
    <message>
        <source>Never</source>
        <translation>Никогда</translation>
    </message>
    <message>
        <source>At time of event</source>
        <translation>Во время события</translation>
    </message>
    <message>
        <source>15 minutes before</source>
        <translation>За 15 минут до</translation>
    </message>
    <message>
        <source>30 minutes before</source>
        <translation>За 30 минут до</translation>
    </message>
    <message>
        <source>1 hour before</source>
        <translation>За 1 час до</translation>
    </message>
    <message>
        <source>1 day before</source>
        <translation>За 1 день до</translation>
    </message>
    <message>
        <source>2 days before</source>
        <translation>За 2 дня до</translation>
    </message>
    <message>
        <source>1 week before</source>
        <translation>За 1 неделю до</translation>
    </message>
    <message>
        <source>On start day (9:00 AM)</source>
        <translation>В начале дня (9:00 утра)</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Тип:</translation>
    </message>
    <message>
        <source>All Day:</source>
        <translation>Весь День:</translation>
    </message>
    <message>
        <source>Remind Me:</source>
        <translation>Напомнить Мне:</translation>
    </message>
    <message>
        <source>Repeat:</source>
        <translation>Повторять:</translation>
    </message>
    <message>
        <source>Daily</source>
        <translation>Ежедневно</translation>
    </message>
    <message>
        <source>Weekdays</source>
        <translation>По будням</translation>
    </message>
    <message>
        <source>Weekly</source>
        <translation>Еженедельно</translation>
    </message>
    <message>
        <source>Monthly</source>
        <translation>Ежемесячно</translation>
    </message>
    <message>
        <source>Yearly</source>
        <translation>Ежегодно</translation>
    </message>
    <message>
        <source>End Repeat:</source>
        <translation>Окончание Повтора:</translation>
    </message>
    <message>
        <source>After</source>
        <translation>После</translation>
    </message>
    <message>
        <source>On</source>
        <translation>Вкл.</translation>
    </message>
    <message>
        <source>time(s)</source>
        <translation>раз(а)</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Сохранить</translation>
    </message>
    <message>
        <source>New event</source>
        <translation>Новое событие</translation>
    </message>
    <message>
        <source>End time must be greater than start time</source>
        <translation>Время окончания должно быть больше времени начала</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>ОК</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Тип</translation>
    </message>
    <message>
        <source>All Day</source>
        <translation>Весь День:</translation>
    </message>
    <message>
        <source>Starts</source>
        <translation>Начало</translation>
    </message>
    <message>
        <source>Ends</source>
        <translation>Завершение</translation>
    </message>
    <message>
        <source>Remind Me</source>
        <translation>Напомнить</translation>
    </message>
    <message>
        <source>Repeat</source>
        <translation>Повторить</translation>
    </message>
    <message>
        <source>End Repeat</source>
        <translation>Завершить повтор</translation>
    </message>
    <message>
        <source>Ends:</source>
        <translation>Окончания:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation>Описание:</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Описание</translation>
    </message>
    <message>
        <source>Starts:</source>
        <translation>Начинания:</translation>
    </message>
    <message>
        <source>Work</source>
        <translation>Работа</translation>
    </message>
    <message>
        <source>Life</source>
        <translation>Семья</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Другое</translation>
    </message>
</context>
<context>
    <name>CSchceduleSearchDateItem</name>
    <message>
        <source>Y</source>
        <translation>Г</translation>
    </message>
    <message>
        <source>M</source>
        <translation>М</translation>
    </message>
    <message>
        <source>D</source>
        <translation>Д</translation>
    </message>
</context>
<context>
    <name>CSchceduleSearchItem</name>
    <message>
        <source>Edit</source>
        <translation>Редактировать</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <source>You are deleting an event.</source>
        <translation>Вы удаляете событие.</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this event?</source>
        <translation>Вы уверены, что хотите удалить это событие?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <source>Do you want to delete all occurrences of this event, or only the selected occurrence?</source>
        <translation>Вы хотите удалить все записи этого события или только выбранную запись?</translation>
    </message>
    <message>
        <source>Delete All</source>
        <translation>Удалить Всё</translation>
    </message>
    <message>
        <source>Delete Only This Event</source>
        <translation>Удалить Только Это Событие</translation>
    </message>
    <message>
        <source>Do you want to delete this and all future occurrences of this event, or only the selected occurrence?</source>
        <translation>Вы хотите удалить эту и все будущие записи этого события или только выбранную запись?</translation>
    </message>
    <message>
        <source>Delete All Future Events</source>
        <translation>Удалить Все Будущие События</translation>
    </message>
    <message>
        <source>All Day</source>
        <translation>Весь День:</translation>
    </message>
</context>
<context>
    <name>CSchceduleSearchView</name>
    <message>
        <source>No search results</source>
        <translation>Ничего не найдено</translation>
    </message>
</context>
<context>
    <name>CScheduleView</name>
    <message>
        <source>ALL DAY</source>
        <translation>ВЕСЬ ДЕНЬ</translation>
    </message>
</context>
<context>
    <name>CWeekWindow</name>
    <message>
        <source>Week</source>
        <translation>Неделя</translation>
    </message>
    <message>
        <source>Y</source>
        <translation>Г</translation>
    </message>
</context>
<context>
    <name>CYearSchceduleItem</name>
    <message>
        <source>All Day</source>
        <translation>Весь День:</translation>
    </message>
</context>
<context>
    <name>CYearSchceduleView</name>
    <message>
        <source>All Day</source>
        <translation>Весь День:</translation>
    </message>
    <message>
        <source>No event</source>
        <translation>Нет событий</translation>
    </message>
</context>
<context>
    <name>CYearWindow</name>
    <message>
        <source>Y</source>
        <translation>Г</translation>
    </message>
</context>
<context>
    <name>CalendarWindow</name>
    <message>
        <source>Calendar</source>
        <translation>Календарь</translation>
    </message>
    <message>
        <source>Calendar is a tool to view dates, and also a smart daily planner to schedule all things in life. </source>
        <translation>Календарь - это инструмент для просмотра дат, а также умный ежедневник для планирования всех событий вашей повседневной жизни.</translation>
    </message>
</context>
<context>
    <name>Calendarmainwindow</name>
    <message>
        <source>Calendar</source>
        <translation>Календарь</translation>
    </message>
    <message>
        <source>Y</source>
        <translation>Г</translation>
    </message>
    <message>
        <source>M</source>
        <translation>М</translation>
    </message>
    <message>
        <source>W</source>
        <translation>Н</translation>
    </message>
    <message>
        <source>D</source>
        <translation>Д</translation>
    </message>
</context>
<context>
    <name>CenterWidget</name>
    <message>
        <source>All Day</source>
        <translation>Весь День:</translation>
    </message>
</context>
<context>
    <name>DragInfoGraphicsView</name>
    <message>
        <source>Edit</source>
        <translation>Редактировать</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <source>New event</source>
        <translation>Новое событие</translation>
    </message>
    <message>
        <source>You are deleting an event.</source>
        <translation>Вы удаляете событие.</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this event?</source>
        <translation>Вы уверены, что хотите удалить это событие?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <source>Do you want to delete all occurrences of this event, or only the selected occurrence?</source>
        <translation>Вы хотите удалить все записи этого события или только выбранную запись?</translation>
    </message>
    <message>
        <source>Delete All</source>
        <translation>Удалить все</translation>
    </message>
    <message>
        <source>Delete Only This Event</source>
        <translation>Удалить только это событие</translation>
    </message>
    <message>
        <source>Do you want to delete this and all future occurrences of this event, or only the selected occurrence?</source>
        <translation>Вы хотите удалить эту и все будущие записи этого события или только выбранную запись?</translation>
    </message>
    <message>
        <source>Delete All Future Events</source>
        <translation>Удалить все будущие события</translation>
    </message>
    <message>
        <source>New Event</source>
        <translation>Новое Событие</translation>
    </message>
</context>
<context>
    <name>Return</name>
    <message>
        <source>Today</source>
        <comment>Return</comment>
        <translation>Сегодня</translation>
    </message>
</context>
<context>
    <name>Return Today</name>
    <message>
        <source>Today</source>
        <comment>Return Today</comment>
        <translation>Сегодня</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Help</source>
        <translation>Помощь</translation>
    </message>
    <message>
        <source>Delete event</source>
        <translation>Удалить событие</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Копировать</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>Вырезать</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Вставить</translation>
    </message>
    <message>
        <source>Select all</source>
        <translation>Выбрать всё</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Удалить</translation>
    </message>
</context>
<context>
    <name>YearFrame</name>
    <message>
        <source>Y</source>
        <translation>Г</translation>
    </message>
</context>
<context>
    <name>today</name>
    <message>
        <source>Today</source>
        <comment>Today</comment>
        <translation>Сегодня</translation>
    </message>
</context>
</TS>